@@ -11,20 +11,20 @@ class UpdatePayoutAccount:
         self.route = "/payoutaccount/update/" + app + "/"
 
     def Process(self, request):
-        json_data = json.dumps(request)
+        #json_data = json.loads(request)
         headers = {"Content-type": "application/json",
                    "Accept": "application/json"}
 
         id = ""
-        if "id" in json_data:
-            id = json_data["id"]
+        if "id" in request:
+            id = request["id"]
         else:
             return {
                 "code": 400,
                 "error": "id is required for update"
             }
 
-        url_info = urlparse.urlparse(self.endpoint + id)
+        url_info = urlparse.urlparse(self.endpoint)
         if url_info.scheme == "https":
             conn = http.client.HTTPSConnection(
                 url_info.hostname, url_info.port or 443)
@@ -33,7 +33,7 @@ class UpdatePayoutAccount:
                 url_info.hostname, url_info.port or 80)
 
         try:
-            conn.request('POST', self.route, json_data, headers)
+            conn.request('POST', (self.route + id), request, headers)
             response = conn.getresponse()
             if response.status == 200:
                 return json.loads(response.read().decode())
